@@ -1,13 +1,10 @@
-use strict;
-use warnings;
-
 package HPC::Runner::Command::stats::Logger::JSON::Long;
 
 use Moose::Role;
 use namespace::autoclean;
 
 use JSON;
-use Data::Dumper;
+use File::Slurp;
 
 sub get_tasks {
     my $self          = shift;
@@ -15,21 +12,20 @@ sub get_tasks {
     my $jobname       = shift;
 
     ##Get the running tasks
-    my $basename = $self->data_tar->basename('.tar.gz');
     my $running_file =
-      File::Spec->catdir( $basename, $jobname, 'running.json' );
+      File::Spec->catdir( $self->data_dir, $jobname, 'running.json' );
 
     my $running = {};
-    if ( $self->archive->contains_file($running_file) ) {
-        my $running_json = $self->archive->get_content($running_file);
+    if ( -e $running_file ) {
+        my $running_json = read_file($running_file);
         $running = decode_json($running_json);
     }
 
     my $complete = {};
     my $complete_file =
-      File::Spec->catdir( $basename, $jobname, 'complete.json' );
-    if ( $self->archive->contains_file($complete_file) ) {
-        my $complete_json = $self->archive->get_content($complete_file);
+      File::Spec->catdir( $self->data_dir, $jobname, 'complete.json' );
+    if ( -e $complete_file ) {
+        my $complete_json = read_file($complete_file);
         $complete = decode_json($complete_json);
     }
 
