@@ -9,32 +9,38 @@ use File::Path qw(make_path remove_tree);
 use IPC::Cmd qw[can_run];
 use File::Temp;
 use File::Spec;
+use File::Slurp;
+use Cwd;
 
-sub make_test_dir{
+sub make_test_dir {
 
     my $tmpdir = File::Spec->tmpdir();
-    my $tmp = File::Temp->newdir(UNLINK =>0, CLEANUP => 0, TEMPLATE => $tmpdir.'/hpcrunnerXXXXXXX');
+    my $tmp    = File::Temp->newdir(
+        UNLINK   => 0,
+        CLEANUP  => 0,
+        TEMPLATE => File::Spec->catdir( $tmpdir, 'hpcrunnerXXXXXXX' )
+    );
     my $test_dir = $tmp->dirname;
 
     remove_tree($test_dir);
     make_path($test_dir);
-    make_path("$test_dir/script");
+    make_path( File::Spec->catdir( $test_dir, 'script' ) );
 
     chdir($test_dir);
 
-    if(can_run('git') && !-d $test_dir."/.git"){
+    if ( can_run('git') && !-d File::Spec->catdir( $test_dir, '.git' ) ) {
         system('git init');
     }
 
-    return $test_dir;
+    # return $test_dir;
+    return cwd();
 }
 
 # Tests were failing if they were running asyncronously.
-# We will just use File::Spec to clean up tmpdir
 sub test_shutdown {
 
     chdir("$Bin");
-    
+
 }
 
 sub print_diff {
@@ -46,18 +52,9 @@ sub print_diff {
     my $diff = diff \$got, \$expect;
     diag("Diff is\n\n$diff\n\n");
 
-    my $fh;
-    open( $fh, ">got.diff" ) or die print "Couldn't open $!\n";
-    print $fh $got;
-    close($fh);
-
-    open( $fh, ">expect.diff" ) or die print "Couldn't open $!\n";
-    print $fh $expect;
-    close($fh);
-
-    open( $fh, ">diff.diff" ) or die print "Couldn't open $!\n";
-    print $fh $diff;
-    close($fh);
+    write_file( 'got.diff',    $got )    or die print "Couldn't write $!\n";
+    write_file( 'expect.diff', $expect ) or die print "Couldn't write $!\n";
+    write_file( 'diff.diff',   $diff )   or die print "Could't write $!\n";
 
     ok(1);
 }
