@@ -73,7 +73,7 @@ sub construct {
 }
 
 sub test_001 : Tags(use_batches) {
-    my $self     = shift;
+    my $self = shift;
 
     my $cwd      = getcwd();
     my $test     = $self->construct;
@@ -159,8 +159,7 @@ sub test_004 : Tags(use_batches) {
 
     my $expect_cmds =
       [     "#TASK tags=Sample_PAG008_V4_E2\n"
-          . "gzip -f Sample_PAG008_V4_E2_read2_trimmomatic_1PE.fastq\n"
-      ];
+          . "gzip -f Sample_PAG008_V4_E2_read2_trimmomatic_1PE.fastq\n" ];
     is_deeply( $cmds, $expect_cmds, 'Commands pass' );
 
     chdir($cwd);
@@ -180,19 +179,18 @@ sub test_005 : Tags(use_batches) {
     $test->cmd( $cmds->[0] );
     $test->_log_commands;
 
-    # diag($test->cmd);
-    # diag($test->data_tar);
-    # diag(Dumper $test->archive->list_files);
-    my $basename      = $test->data_tar->basename('.tar.gz');
-    my $complete_file = File::Spec->catdir( $basename, 'job', 'complete.json' );
-    my $running_file  = File::Spec->catdir( $basename, 'job', 'running.json' );
+    my $complete_file =
+      File::Spec->catdir( $test->data_dir, 'job', 'complete.json' );
+    my $running_file =
+      File::Spec->catdir( $test->data_dir, 'job', 'running.json' );
 
-    ok( $test->archive->contains_file($complete_file) );
-    ok( $test->archive->contains_file($running_file) );
+    ok( -e $complete_file );
+    ok( -e $running_file );
+
+    # $test->lock_file->touchpath;
+    # my $ret = $test->check_lock;
+    # is( $ret, 0, 'Lock file exists and should not be removed' );
 
-    $test->lock_file->touchpath;
-    my $ret = $test->check_lock;
-    is($ret, 0, 'Lock file exists and should not be removed');
     # diag($test->archive->get_content($complete_file));
     ok(1);
 
@@ -200,33 +198,4 @@ sub test_005 : Tags(use_batches) {
     remove_tree($test_dir);
 }
 
-sub test_006 {
-    my $test     = construct();
-    my $test_dir = getcwd();
-
-    my $basename = $test->data_tar->basename('.tar.gz');
-    my $job_dir = File::Spec->catdir( $basename, 'job', );
-
-    $test->counter(1);
-    $test->cmd('hello');
-    $test->start_command_log('1234');
-
-    is( $test->lock_file->exists, undef, 'Lock does not exist' );
-    $test->write_lock($job_dir);
-    is( $test->lock_file->exists, 1, 'Lock exists' );
-    $test->lock_file->remove;
-    is( $test->lock_file->exists, undef, 'Lock does not exist' );
-
-    $test->archive->add_data( 'some_file', 'hello' );
-    $test->archive->add_data( File::Spec->catdir( $basename, 'THING' ),
-        'some_data' );
-
-    $test->archive->write( $test->data_tar, 1 );
-    $test->archive->read( $test->data_tar );
-
-    diag( 'Data tar is ' . $test->data_tar );
-    chdir($Bin);
-    remove_tree($test_dir);
-}
-
 1;
